Elekta Task Dataset
-------------------

The data  used in this example is from the publicly available [Wakeman-Henson](https://www.nature.com/articles/sdata20151) dataset. Although, the data was recorded while the participants performed a task, we will preprocess it as if it were resting-state data. The data was collected using an Elekta scanner.

Example scripts for preprocessing and source reconstructing Elekta data are contained in `/preproc`.
